%define         perversion      1.-94.-2
Name:           clc-intercal
Version:        0
Release:        0.17.%(echo %{perversion}|sed -e's/-/_/g')%{?dist}
Summary:        Compiler for the INTERCAL language
License:        BSD
Group:          Development/Libraries
URL:            http://clc.intercal.org.uk/
Source0:        http://overload.intercal.org.uk/clc/CLC-INTERCAL-%{perversion}/CLC-INTERCAL-%{perversion}.tar.gz
# under perl-5.12, uc warns when passed undef
# (and patch doesn't work in build)
Source1:        %{name}-perl-5-12.patch
# fix a charset detection bug
Source2:        %{name}-guess-charset.patch
# fix a badly written test
Source3:        %{name}-tests.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:      noarch
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(Curses)
BuildRequires:  perl(Gtk2)
BuildRequires:  perl(version)

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{perversion}}

%{?filter_setup:
%filter_from_provides /^perl(MY)/d
%?perl_default_filter
}
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}perl\\(MY\\)

%description
This package provides a Perl-based compiler for the INTERCAL programming
language, usable either from the command line or as a Perl module.

CLC-INTERCAL is designed to be almost compatible with the original (Princeton
1972) compiler. It also implements several extensions to the original language,
including support for object orientation, operator overloading and quantum
computing. 

%package        UI-X
Summary:        Graphical user interface to CLC-INTERCAL
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description    UI-X
This package installs a graphical user interface to CLC-INTERCAL.

At present, only the INTERCAL calculator, "intercalc", uses this interface,
although a future release of "sick" will be able to use it as well.


%prep
%setup -q -n CLC-INTERCAL-%{perversion}


%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
patch -s -p1 --fuzz=0 <%{SOURCE1}
patch -s -p1 --fuzz=0 <%{SOURCE2}
patch -s -p1 --fuzz=0 <%{SOURCE3}
# parallel build fails - don't use -j
make

%install
rm -rf %{buildroot}

make install PERL_INSTALL_ROOT=%{buildroot}

find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -depth -type d -exec rmdir {} 2>/dev/null \;

%{_fixperms} %{buildroot}/*
find %{buildroot} -type f -name \*.pm | xargs chmod 644

# manually install documentation
mkdir -p %{buildroot}%{_pkgdocdir}
cp -p CLC-INTERCAL-Base-%{perversion}/{Changes,COPYING,MISSING,README,WISHLIST} \
  %{buildroot}%{_pkgdocdir}
for pkg in Docs ICALC INET UI-Curses UI-Line UI-X; do
  cp -p CLC-INTERCAL-${pkg}-%{perversion}/Changes \
    %{buildroot}%{_pkgdocdir}/Changes-${pkg}
  cp -p CLC-INTERCAL-${pkg}-%{perversion}/README \
    %{buildroot}%{_pkgdocdir}/README-${pkg}
done
cp -ap CLC-INTERCAL-Docs-%{perversion}/doc/{examples,html,INTERNET} \
  %{buildroot}%{_pkgdocdir}

# convert "bookworm" and "change" characters to utf-8 friendly versions
for doc in $(find %{buildroot}%{_pkgdocdir}/{examples,INTERNET} -type f); do
  sed -i -e 's/\o245/V\o010-/g' -e 's/\o242/c\o010\//g' $doc
done

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%docdir %{_pkgdocdir}
%{_pkgdocdir}
%{perl_vendorlib}/*
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man3/*
# These are in UI-X sub-package.
%exclude %{_pkgdocdir}/*-UI-X
%exclude %{perl_vendorlib}/Language/INTERCAL/Interface/X.pm
# Installation helper, not required for runtime, but has a dependency on
# ExtUtils::MakeMaker. Exclude it to avoid dependency bloat.
%exclude %{perl_vendorlib}/Language/INTERCAL/InstallModule.pm

%files UI-X
%defattr(-,root,root,-)
%{_pkgdocdir}/*-UI-X
%{perl_vendorlib}/Language/INTERCAL/Interface/X.pm


%changelog
* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.17.1._94._2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 10 2013 Iain Arnell <iarnell@gmail.com> 0-0.16.1._94._2
- use _pkgdocdir macro to install docs to unperversioned location

* Sun Aug 04 2013 Petr Pisar <ppisar@redhat.com> - 0-0.15.1._94._2
- Perl 5.18 rebuild

* Fri Aug 02 2013 Iain Arnell <iarnell@gmail.com> 0-0.14.1._94._2
- Patch to fix a badly written test

* Fri Aug 02 2013 Iain Arnell <iarnell@gmail.com> 0-0.13.1._94._2
- Patch to fix a character set detection bug revealed under Perl 5.18

* Mon Jul 22 2013 Petr Pisar <ppisar@redhat.com> - 0-0.12.1._94._2
- Perl 5.18 rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.11.1._94._2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.10.1._94._2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun 14 2012 Petr Pisar <ppisar@redhat.com> - 0-0.9.1._94._2
- Perl 5.16 rebuild

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.8.1._94._2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Jul 27 2011 Iain Arnell <iarnell@gmail.com> 0-0.7.1._94._2
- update filtering for rpm 4.9
- exclude InstallModule.pm to avoid dependency bloat

* Tue Jun 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0-0.6.1._94._2
- Perl mass rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.5.1._94._2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri May 28 2010 Iain Arnell <iarnell@gmail.com> 0-0.4.1._94._2
- tiny tweaklet for perl-5.12
- use perl_default_filter

* Mon Dec 14 2009 Iain Arnell <iarnell@gmail.com> 0-0.3.1._94._2
- update Source0 url (upstream has moved)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.2.1._94._2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jan 29 2009 Iain Arnell <iarnell@gmail.com> 0-0.0.1._94._2
- pre-pre-escape 1.-94.-2

